Package: jetpack
Type: Package
Title: A Friendly Package Manager
Version: 0.5.5
Date: 2022-10-30
Authors@R: person("Andrew", "Kane", email = "andrew@chartkick.com", role = c("aut", "cre"))
Description: Manage project dependencies from your DESCRIPTION file. Create a reproducible virtual environment with minimal additional files in your project. Provides tools to add, remove, and update dependencies as well as install existing dependencies with a single function.
URL: https://github.com/ankane/jetpack
BugReports: https://github.com/ankane/jetpack/issues
License: MIT + file LICENSE
RoxygenNote: 7.2.1
Roxygen: list(markdown = TRUE)
Encoding: UTF-8
Imports: renv (>= 0.13.1), remotes (>= 2.0.3), desc (>= 1.2.0), docopt
        (>= 0.4)
Suggests: testthat, withr, packrat
Config/testthat/start-first: cli, global
Author: Andrew Kane [aut, cre]
Maintainer: Andrew Kane <andrew@chartkick.com>
Built: R 4.4.0; ; 2024-04-29 14:27:55 UTC; unix
